@@ -5,11 +5,11 @@ import shutil
 
 def create_file(sfilepath: str, dfilepath: str, props: dict):
     """Lee archivo original, reemplaza las variables y crea archivo de salida"""
-    with open(sfilepath, "r") as fl:
+    with open(sfilepath, "r", encoding="utf-8") as fl:
         data = fl.read()
         for prop, value in props.items():
             data = data.replace(prop, value)
-    with open(dfilepath, "w") as fl:
+    with open(dfilepath, "w", encoding="utf-8") as fl:
         fl.write(data)
 
 
